microsoft_viewer library

Classes

MicrosoftViewer
The main dart file that takes the bytes data passed and then parses the files and displays the information.
MicrosoftViewerState
Stateful widget of the package