MsTableRow class

Constructors

MsTableRow(bool isFirstRow, bool isLastRow, bool isFirstCol, bool isLastCol)

Properties

cells ↔ List<MsTableCell>
getter/setter pair
gridSpan ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFirstCol ↔ bool
getter/setter pair
isFirstRow ↔ bool
getter/setter pair
isLastCol ↔ bool
getter/setter pair
isLastRow ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited