PresentationColorSchemes class

Constructors

PresentationColorSchemes(String id, String name, String sysClrName, String sysClrLast, String srgbClr)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
srgbClr String
getter/setter pair
sysClrLast String
getter/setter pair
sysClrName String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited